export * from './utils';
declare type ScrollAlignment = 'start' | 'center' | 'end' | 'auto';
interface ScrollToOptions {
    align: ScrollAlignment;
}
declare type ScrollToOffsetOptions = ScrollToOptions;
declare type ScrollToIndexOptions = ScrollToOptions;
export interface Range {
    startIndex: number;
    endIndex: number;
    overscan: number;
    count: number;
}
declare type Key = number | string;
interface Item {
    key: Key;
    index: number;
    start: number;
    end: number;
    size: number;
}
interface Rect {
    width: number;
    height: number;
}
export interface VirtualItem<TItemElement> extends Item {
    measureElement: (el: TItemElement | null) => void;
}
export declare const defaultKeyExtractor: (index: number) => number;
export declare const defaultRangeExtractor: (range: Range) => number[];
export declare const observeElementRect: (instance: Virtualizer<any, any>, cb: (rect: Rect) => void) => (() => void) | undefined;
export declare const observeWindowRect: (instance: Virtualizer<any, any>, cb: (rect: Rect) => void) => (() => void) | undefined;
export declare const observeElementOffset: (instance: Virtualizer<any, any>, cb: (offset: number) => void) => (() => void) | undefined;
export declare const observeWindowOffset: (instance: Virtualizer<any, any>, cb: (offset: number) => void) => (() => void) | undefined;
export declare const measureElement: (element: unknown, instance: Virtualizer<any, any>) => number;
export declare const windowScroll: (offset: number, canSmooth: boolean, instance: Virtualizer<any, any>) => void;
export declare const elementScroll: (offset: number, canSmooth: boolean, instance: Virtualizer<any, any>) => void;
export interface VirtualizerOptions<TScrollElement = unknown, TItemElement = unknown> {
    count: number;
    getScrollElement: () => TScrollElement;
    estimateSize: (index: number) => number;
    scrollToFn: (offset: number, canSmooth: boolean, instance: Virtualizer<TScrollElement, TItemElement>) => void;
    observeElementRect: (instance: Virtualizer<TScrollElement, TItemElement>, cb: (rect: Rect) => void) => void | (() => void);
    observeElementOffset: (instance: Virtualizer<TScrollElement, TItemElement>, cb: (offset: number) => void) => void | (() => void);
    debug?: any;
    initialRect?: Rect;
    onChange?: (instance: Virtualizer<TScrollElement, TItemElement>) => void;
    measureElement?: (el: TItemElement, instance: Virtualizer<TScrollElement, TItemElement>) => number;
    overscan?: number;
    horizontal?: boolean;
    paddingStart?: number;
    paddingEnd?: number;
    scrollPaddingStart?: number;
    scrollPaddingEnd?: number;
    initialOffset?: number;
    getItemKey?: (index: number) => Key;
    rangeExtractor?: (range: Range) => number[];
    enableSmoothScroll?: boolean;
}
export declare class Virtualizer<TScrollElement = unknown, TItemElement = unknown> {
    private unsubs;
    options: Required<VirtualizerOptions<TScrollElement, TItemElement>>;
    scrollElement: TScrollElement | null;
    private measurementsCache;
    private itemMeasurementsCache;
    private pendingMeasuredCacheIndexes;
    private scrollRect;
    private scrollOffset;
    private destinationOffset;
    private scrollCheckFrame;
    constructor(opts: VirtualizerOptions<TScrollElement, TItemElement>);
    setOptions: (opts: VirtualizerOptions<TScrollElement, TItemElement>) => void;
    private notify;
    private cleanup;
    _didMount: () => () => void;
    _willUpdate: () => void;
    private getSize;
    private getMeasurements;
    private calculateRange;
    private getIndexes;
    getVirtualItems: () => VirtualItem<TItemElement>[];
    scrollToOffset: (toOffset: number, { align }?: ScrollToOffsetOptions) => void;
    scrollToIndex: (index: number, { align, ...rest }?: ScrollToIndexOptions) => void;
    getTotalSize: () => number;
    private _scrollToOffset;
    measure: () => void;
}
